@@ -66,7 +66,7 @@ public:
     /**
      * Destroys the ldap search dialog.
      */
-    ~LdapSearchDialog();
+    ~LdapSearchDialog() override;
 
     /**
      * Sets the @p text in the search line edit.
@@ -101,14 +101,9 @@ private:
     Private *const d;
 
     Q_PRIVATE_SLOT(d, void slotAddResult(const KLDAP::LdapClient &, const KLDAP::LdapObject &))
-    Q_PRIVATE_SLOT(d, void slotSetScope(bool))
     Q_PRIVATE_SLOT(d, void slotStartSearch())
     Q_PRIVATE_SLOT(d, void slotStopSearch())
     Q_PRIVATE_SLOT(d, void slotSearchDone())
-    Q_PRIVATE_SLOT(d, void slotError(const QString &))
-    Q_PRIVATE_SLOT(d, void slotSelectAll())
-    Q_PRIVATE_SLOT(d, void slotUnselectAll())
-    Q_PRIVATE_SLOT(d, void slotSelectionChanged())
     //@endcond
 };
 }
