@@ -48,12 +48,11 @@ class BroadcastStatusPrivate
 {
 public:
     BroadcastStatusPrivate()
-        : mTransientActive(false)
     {
     }
 
     QString mStatusMsg;
-    bool mTransientActive;
+    bool mTransientActive = false;
 };
 
 BroadcastStatus::BroadcastStatus()
@@ -67,11 +66,6 @@ BroadcastStatus::~BroadcastStatus()
     delete d;
 }
 
-QString BroadcastStatus::statusMsg() const
-{
-    return d->mStatusMsg;
-}
-
 void BroadcastStatus::setStatusMsg(const QString &message)
 {
     d->mStatusMsg = message;
