@@ -523,8 +523,8 @@ void AddresseeLineEdit::addContact(const KContacts::Addressee &addr, int weight,
 
         if (!append.isEmpty()) {
             appendix = QStringLiteral(" (%1)");
-            append = append.replace(QLatin1Char('('), QStringLiteral("["));
-            append = append.replace(QLatin1Char(')'), QStringLiteral("]"));
+            append.replace(QLatin1Char('('), QStringLiteral("["));
+            append.replace(QLatin1Char(')'), QStringLiteral("]"));
             appendix = appendix.arg(append);
         }
 
@@ -652,7 +652,7 @@ void AddresseeLineEdit::loadContacts()
             name = KEmailAddress::quoteNameIfNecessary(name);
             if ((name[0] == QLatin1Char('"')) && (name[name.length() - 1] == QLatin1Char('"'))) {
                 name.remove(0, 1);
-                name.truncate(name.length() - 1);
+                name.chop(1);
             }
             addr.setNameFromString(name);
             addr.insertEmail(email, true);
@@ -942,7 +942,7 @@ void AddresseeLineEdit::expandGroups()
         addresses.removeAll(group.name());
         expandJob->start();
     }
-    setText(addresses.join(QStringLiteral(", ")));
+    setText(addresses.join(QLatin1String(", ")));
     d->groupsClear();
 }
 
