@@ -21,28 +21,20 @@
 #include <QWidget>
 #include <QVBoxLayout>
 
-#include <KAboutData>
-
-#include <KLocalizedString>
 #include "../src/libkdepimakonadi/addressline/addresslineedit/addresseelineedit.h"
 
 #include <QApplication>
 #include <QCommandLineParser>
-#include <QCommandLineOption>
 #include <QStandardPaths>
 
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    KAboutData aboutData(QStringLiteral("testaddresseelineedit"), i18n("Test AddresseeLineEdit"), QStringLiteral("0.1"));
     QStandardPaths::setTestModeEnabled(true);
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     QWidget *w = new QWidget;
     QVBoxLayout *vbox = new QVBoxLayout(w);
